SystemOrganization addCategory: #'AdventureThing-Core'!
SystemOrganization addCategory: #'AdventureThing-Core-Tests'!

!Symbol methodsFor: '*adventurething-core' stamp: 'StuartHerring 11/23/2012 18:40'!
asDirection
	^ATDirection fromSymbol: self! !

TestCase subclass: #ATExitTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core-Tests'!

!ATExitTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:33'!
testDirection
	 | exit |
	exit := ATExit from: nil to: nil direction: #east.
	
	self assert: exit direction equals: ATDirection east
! !

!ATExitTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:29'!
testFromAndTo
	 | exit l1 l2 |
	l1 := ATLocation new.
	l2 := ATLocation new.
	exit := ATExit from: l1 to: l2.
	
	self assert: exit origin equals: l1.
	self assert: exit destination equals: l2.! !

!ATExitTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:28'!
testNewInstanceWithNoDirectionIsSpecialDirection
	 | exit |
	exit := ATExit from: nil to: nil.
	
	self assert: exit direction equals: ATDirection special.! !

!ATExitTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:33'!
testReciprocalDirection
	 | exit |
	exit := (ATExit from: nil to: nil direction: #east) reciprocal.

	self assert: exit direction equals: ATDirection west! !

!ATExitTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:30'!
testReciprocalFromAndTo
	 | exit l1 l2 |
	l1 := ATLocation new.
	l2 := ATLocation new.
	exit := (ATExit from: l1 to: l2) reciprocal.
	
	self assert: exit origin equals: l2.
	self assert: exit destination equals: l1.! !

TestCase subclass: #ATLocationTest
	instanceVariableNames: 'loc'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core-Tests'!

!ATLocationTest commentStamp: '<historical>' prior: 0!
An ATLocationTest is a test class for testing the behavior of ATLocation!

!ATLocationTest methodsFor: 'tests' stamp: 'StuartHerring 11/23/2012 18:13'!
setUp
	super setUp.
	
	loc := ATLocation new.! !

!ATLocationTest methodsFor: 'tests' stamp: 'StuartHerring 11/23/2012 18:16'!
testAddExit
	| exit |
	exit := ATExit new.
	
	loc addExit: exit.
	self assert: (loc exits includes: exit)! !

!ATLocationTest methodsFor: 'tests' stamp: 'StuartHerring 11/24/2012 13:36'!
testAddExitReturnsExit
	| exit |
	exit := ATExit new.
	
	
	self assert: (loc addExit: exit) equals: exit.! !

!ATLocationTest methodsFor: 'tests' stamp: 'StuartHerring 11/23/2012 18:47'!
testAddExitWithReciprocal
	| exit loc2 |
	loc2 := ATLocation new.
	exit := ATExit from: loc to: loc2 direction: #east.
	
	loc addExitWithReciprocal: exit.
	self assert: (loc exitAt: #east) destination equals: loc2.
	self assert: (loc2 exitAt: #west) destination equals: loc.! !

!ATLocationTest methodsFor: 'tests-initialize' stamp: 'StuartHerring 11/24/2012 13:23'!
testRemoveExit
	| exit |
	exit := ATExit new.
	
	loc addExit: exit.
	loc removeExit: exit.
	self deny: (loc exits includes: exit)! !

!ATLocationTest methodsFor: 'tests-initialize' stamp: 'StuartHerring 11/24/2012 13:48'!
testRemoveExitsTo
	| exit l2 |
	l2 := ATLocation new.
	exit := ATExit from: loc to: l2.
	
	loc addExit: exit.
	loc removeExitsTo: l2.
	self deny: (loc exits includes: exit)! !

TestCase subclass: #ATWorldTest
	instanceVariableNames: 'world'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core-Tests'!

!ATWorldTest commentStamp: '<historical>' prior: 0!
An ATWorldTest is a test class for testing the behavior of ATWorld!

!ATWorldTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:09'!
setUp
	super setUp.
	
	world := ATWorld new.! !

!ATWorldTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:10'!
testAddLocation
	| l |
	l := ATLocation new.
	
	world addLocation: l.
	
	self assert: (world locations includes: l)! !

!ATWorldTest methodsFor: 'tests' stamp: 'StuartHerring 11/24/2012 13:34'!
testAddLocationReturnsLocation
	| l |
	l := ATLocation new.
	
	self assert: (world addLocation: l )equals: l! !

!ATWorldTest methodsFor: 'tests-initialize-release' stamp: 'StuartHerring 11/24/2012 13:29'!
testRemoveLocation
	| l |
	l := ATLocation new.
	
	world addLocation: l.
	world removeLocation: l.
	
	self deny: (world locations includes: l)! !

!ATWorldTest methodsFor: 'tests' stamp: 'StuartHerring 11/24/2012 13:35'!
testRemoveLocationRemovesIncomingExits
	| l l2 exit |
	l := 	world addLocation: ATLocation new.
	l2 := world addLocation: ATLocation new.

	exit := l2 addExit:  (ATExit from: l2 to: l ).
		
	world removeLocation: l.
		
	self deny: (l2 exits includes: exit)! !

Object subclass: #ATDirection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

ATDirection class
	instanceVariableNames: 'instance'!

ATDirection class
	instanceVariableNames: 'instance'!

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:38'!
asDirection
	^self instance! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:38'!
directions
	^self allSubclasses collect: [ :c | c instance  ]! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:34'!
down
	^ATDown instance! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:34'!
east
	^ATEast instance! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:38'!
fromSymbol: aSymbol
	^(self allSubclasses 
		detect: [ :d | d symbol = aSymbol ])
			instance! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:41'!
instance
	^instance ifNil: [ instance := self new ]! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:34'!
north
	^ATNorth instance! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:34'!
south
	^ATSouth instance! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:36'!
special
	^ATSpecial instance.! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:38'!
symbol
	self subclassResponsibility! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:35'!
up
	^ATUp instance! !

!ATDirection class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:35'!
west
	^ATWest instance! !

!ATDirection methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:38'!
asDirection
	^self! !

!ATDirection methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:33'!
displayName
	^self symbol asCapitalizedPhrase! !

!ATDirection methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/28/2012 19:23'!
fuelAccept: aGeneralMapper
	^aGeneralMapper visitGlobalSend: self 
                name: self class name
                selector: #instance! !

!ATDirection methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:25'!
reciprocal
	^self! !

!ATDirection methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:40'!
symbol
	^self class symbol! !

ATDirection subclass: #ATDown
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATDown class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/24/2012 10:07'!
symbol
	^#down! !

!ATDown methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:26'!
reciprocal
	^self class up! !

ATDirection subclass: #ATEast
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATEast class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/24/2012 10:07'!
symbol
	^#east! !

!ATEast methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:39'!
reciprocal
	^self class west! !

ATDirection subclass: #ATNorth
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATNorth class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/24/2012 10:07'!
symbol
	^#north! !

!ATNorth methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:39'!
reciprocal
	^self class south! !

ATDirection subclass: #ATSouth
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATSouth class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/24/2012 10:07'!
symbol
	^#south! !

!ATSouth methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:39'!
reciprocal
	^self class north! !

ATDirection subclass: #ATSpecial
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATSpecial class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:37'!
symbol
	^#special! !

!ATSpecial methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:39'!
reciprocal
	^self! !

ATDirection subclass: #ATUp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATUp class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/24/2012 10:08'!
symbol
	^#up! !

!ATUp methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:39'!
reciprocal
	^self class down! !

ATDirection subclass: #ATWest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATWest class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/24/2012 10:08'!
symbol
	^#west! !

!ATWest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 16:39'!
reciprocal
	^self reciprocal east! !

Object subclass: #ATExit
	instanceVariableNames: 'destination direction origin'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATExit class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:38'!
from: origin to: destination
	^self basicNew
		initializeWithFrom: origin to: destination direction: ATDirection special;
		yourself! !

!ATExit class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:40'!
from: origin to: destination direction: aDirection
	^self basicNew
		initializeWithFrom: origin to: destination direction: aDirection;
		yourself! !

!ATExit methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:34'!
destination
	^ destination! !

!ATExit methodsFor: 'accessing' stamp: 'StuartHerring 11/24/2012 13:53'!
destination: anObject
	destination := anObject! !

!ATExit methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:34'!
direction
	^ direction! !

!ATExit methodsFor: 'accessing' stamp: 'StuartHerring 11/24/2012 13:53'!
direction: anObject
	direction := anObject! !

!ATExit methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/23/2012 18:40'!
initializeWithFrom: aLocation to: anotherLocation direction: aDirection
	self initialize.
	origin := aLocation.
	destination := anotherLocation.
	direction := aDirection asDirection.! !

!ATExit methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:34'!
origin
	^ origin! !

!ATExit methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:44'!
reciprocal
	^self class
		from: destination to: origin direction: direction reciprocal! !

Object subclass: #ATLocation
	instanceVariableNames: 'description exits name id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATLocation class methodsFor: 'instance creation' stamp: 'StuartHerring 11/23/2012 18:06'!
name: name

	^ self new
		name: name;
		yourself! !

!ATLocation methodsFor: 'initialize' stamp: 'StuartHerring 11/24/2012 13:36'!
addExit: anExit
	^exits add: anExit! !

!ATLocation methodsFor: 'initialize' stamp: 'StuartHerring 11/23/2012 18:48'!
addExitWithReciprocal: anExit
	exits add: anExit.
	anExit destination addExit: anExit reciprocal.! !

!ATLocation methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:04'!
description
	^ description! !

!ATLocation methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:04'!
description: anObject
	description := anObject! !

!ATLocation methodsFor: 'initialize' stamp: 'StuartHerring 11/23/2012 18:49'!
exitAt: aSymbolOrDirection
	| dir |
	dir := aSymbolOrDirection asDirection.
	^exits detect: [ :exit | exit direction = dir ]! !

!ATLocation methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:45'!
exits
	^exits! !

!ATLocation methodsFor: 'accessing' stamp: 'StuartHerring 11/24/2012 14:57'!
id
	^id! !

!ATLocation methodsFor: 'accessing' stamp: 'StuartHerring 11/24/2012 14:57'!
id: anId
	id := anId! !

!ATLocation methodsFor: 'accessing' stamp: 'StuartHerring 11/24/2012 14:57'!
initialize
	super initialize.
	exits := OrderedCollection new.
	id := nil.! !

!ATLocation methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:05'!
name
	^name! !

!ATLocation methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 18:04'!
name: anObject
	name := anObject! !

!ATLocation methodsFor: 'initialize' stamp: 'StuartHerring 11/24/2012 13:25'!
removeExit: anExit
	^self exits remove: anExit! !

!ATLocation methodsFor: 'initialize' stamp: 'StuartHerring 11/24/2012 13:49'!
removeExitsTo: aLocation
	^self exits removeAllSuchThat: [ :e | e destination = aLocation ]! !

Object subclass: #ATRepository
	instanceVariableNames: 'directory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATRepository class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 17:47'!
default
	^self on: self defaultDir! !

!ATRepository class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 17:54'!
defaultDir
	^(FileSystem workingDirectory / 'saves') ensureDirectory! !

!ATRepository class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 17:45'!
on: aDirectory
	^self basicNew
		initializeWithDirectory: aDirectory.! !

!ATRepository methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/26/2012 19:49'!
initializeWithDirectory: aDirectory
	self initialize.
	directory := aDirectory! !

!ATRepository methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/28/2012 21:03'!
save: aWorld
	FLSerializer newDefault
		serialize: aWorld
		on: ((directory / aWorld name asFileName) writeStream).
	^aWorld! !

!ATRepository methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/28/2012 19:24'!
worldNamed: aName
	^FLMaterializer newDefault materializeFrom: (directory / aName) readStream! !

!ATRepository methodsFor: 'as yet unclassified' stamp: 'StuartHerring 11/25/2012 18:15'!
worldNames
	^directory fileNames! !

Object subclass: #ATWorld
	instanceVariableNames: 'name locations description id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AdventureThing-Core'!

!ATWorld methodsFor: 'initialize-release' stamp: 'StuartHerring 11/24/2012 14:58'!
addLocation: aLocation
	^(locations add: aLocation)
		id: self nextId;
		yourself.
! !

!ATWorld methodsFor: 'accessing' stamp: 'StuartHerring 11/17/2012 17:43'!
description
	^description! !

!ATWorld methodsFor: 'accessing' stamp: 'StuartHerring 11/17/2012 17:43'!
description: aString
	description := aString! !

!ATWorld methodsFor: 'initialize-release' stamp: 'StuartHerring 11/24/2012 14:59'!
initialize
	super initialize.
	locations := OrderedCollection new.
	id := 0.! !

!ATWorld methodsFor: 'initialize-release' stamp: 'StuartHerring 11/24/2012 14:59'!
locationById: anId
	^locations detect: [ :l | l id = anId ]! !

!ATWorld methodsFor: 'accessing' stamp: 'StuartHerring 11/23/2012 17:36'!
locations
	^ locations! !

!ATWorld methodsFor: 'accessing' stamp: 'StuartHerring 11/16/2012 18:44'!
name
	^ name! !

!ATWorld methodsFor: 'accessing' stamp: 'StuartHerring 11/17/2012 16:34'!
name: anObject
	name := anObject! !

!ATWorld methodsFor: 'initialize-release' stamp: 'StuartHerring 11/24/2012 15:01'!
nextId
	^id := (id ifNil: [0 ]) + 1! !

!ATWorld methodsFor: 'initialize-release' stamp: 'StuartHerring 11/24/2012 13:50'!
removeLocation: aLocation
	locations remove: aLocation.
	locations do: [ :loc | loc removeExitsTo: aLocation ]! !
